Module plugin_component

Module plugin_component 

Core plugin integration for the adaptive runtime.

Structs

ComponentSpec
One configured adaptive component.

Constants

ADAPTIVE_PLUGIN_KIND
The plugin kind registered by the adaptive crate.

Functions

deregister_adaptive_component
Deregisters the adaptive component kind from the core plugin registry.
register_adaptive_component
Registers the adaptive component kind in the core plugin registry.