register_adaptive_component

Function register_adaptive_component 

pub fn register_adaptive_component() -> Result<()>
Registers the adaptive component kind in the core plugin registry.

Call this during startup before validating or initializing plugin configs that contain adaptive components.

Returns

A core plugin Result that is Ok(()) when the adaptive component kind is available in the registry.

Errors

Returns an error when registration fails for a reason other than an already registered adaptive component.

Notes

Re-registering the adaptive component is treated as success when the existing registration already resolves to the adaptive plugin kind.