Module cache

Module cache 

Hot-cache structures used by the adaptive runtime on the intercept path. Hot-cache state shared by adaptive runtime features.

Structs

HotCache
In-memory cache of adaptive artifacts needed on the hot path.